@@ -4,8 +4,8 @@
 
 ;; Author: Thierry Banel tbanelwebmin at free dot fr
 ;; Contributors:
-;; Package-Version: 20260208.818
-;; Package-Revision: 7d32eadb97d6
+;; Package-Version: 20260217.1139
+;; Package-Revision: bd9edf54bdd5
 ;; Keywords: data, extensions
 ;; Package-Requires: ((emacs "24.3"))
 ;; URL: https://github.com/tbanel/orgtbljoin/blob/master/README.org
@@ -119,7 +119,7 @@
     `(while (not (listp (car ,table)))
        (orgtbl-join--pop-simple ,table)))
 
-  (defmacro string-match-p (regexp string &optional start)
+  (defmacro orgtbl-join--string-match-p (regexp string &optional start)
     "Same as standard `string-match-p'
 but written as a defmacro instead of a defsubst,
 which saves 4 or 5 byte-codes at each call."
@@ -1724,6 +1724,17 @@ then proceed to folding, otherwise unfold."
       (org-TAB-begin-join-fold)
     (org-TAB-begin-join-unfold)))
 
+(defun orgtbl-join--insert-remove-pair-from-alist (tag alist)
+  "Helper function for folding a pair (TAG . VALUE) in ALIST."
+  (let ((value
+         (orgtbl-join--nil-if-empty
+          (orgtbl-join--alist-get-remove tag alist))))
+    (if value
+        (insert
+         (format " %s %s"
+                 tag
+                 (prin1-to-string value))))))
+
 (defun orgtbl-join-get-all-unfolded ()
   "Prepare an a-list of all unfolded parameters."
   (interactive)
@@ -1764,14 +1775,6 @@ NEW being the result of executing (GETTER OLD)"
 
 ;; bazilo]
 
-(defun orgtbl-join--insert-remove-pair-from-alist (tag alist)
-  "Helper function for folding a pair (TAG . VALUE) in ALIST."
-  (let ((value
-         (orgtbl-join--nil-if-empty
-          (orgtbl-join--alist-get-remove tag alist))))
-    (if value
-        (insert (format " %s \"%s\"" tag value)))))
-
 (defun org-TAB-begin-join-fold ()
   "Turn all lines of the form #+join: … into a single line.
 That is, fold the may lines of the form:
